setup

package
v0.0.0-...-39d98de Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 25, 2026 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Configuration

func Configuration(name string) *gopolutils.Exception

Setup the folders used by the application. If any of the given folders can not be setup, an gopolutils.IOError is returned.

func GUI

func GUI(passwords table.Table[password.Password], manager *parol.Parol, configuration settings.Settings) *ui.GUI

Setup the gui based on its parts. Returns the gui of the application.

func GetAssetPath

func GetAssetPath() *fayl.Path

Obtain the asset path of the application. Returns the asset path of the application.

func GetBasePath

func GetBasePath() *fayl.Path

Obtain the base path of the application. Returns the base path of the application.

func GetDataFolder

func GetDataFolder() *fayl.Path

Obtain the data path of the application. Returns the data path of the application.

func GetDatabaseFile

func GetDatabaseFile() *fayl.Path

Obtain the database path of the application. Returns the database path of the application.

func GetKeyFile

func GetKeyFile() *fayl.Path

Obtain the key path of the application. Returns the key path of the application.

func GetSettingsPath

func GetSettingsPath() *fayl.Path

Obtain the settings path of the application. Returns the settings path of the application.

func Passwords

func Passwords(keyFile, passwordFile *fayl.Path, tableName string, driver table.Driver) (*parol.Parol, table.Table[password.Password])

Setup the password logic for the application. Returns a tuple containing the password manager and the table of passwords.

Types

This section is empty.

Jump to